@@ -1,20 +1,27 @@
-{-# LANGUAGE DataKinds #-}
-{-# LANGUAGE FlexibleContexts #-}
+{-# LANGUAGE DataKinds         #-}
+{-# LANGUAGE FlexibleContexts  #-}
 {-# LANGUAGE OverloadedStrings #-}
-{-# LANGUAGE TypeOperators #-}
+{-# LANGUAGE TypeOperators     #-}
 module Servant.Server.RouterSpec (spec) where
 
-import           Control.Monad                  (unless)
-import           Data.Proxy                     (Proxy(..))
-import           Data.Text                      (unpack)
-import           Network.HTTP.Types             (Status (..))
-import           Network.Wai                    (responseBuilder)
-import           Network.Wai.Internal           (Response (ResponseBuilder))
-import           Test.Hspec
-import           Test.Hspec.Wai                 (get, shouldRespondWith, with)
+import           Control.Monad
+                 (unless)
+import           Data.Proxy
+                 (Proxy (..))
+import           Data.Text
+                 (unpack)
+import           Network.HTTP.Types
+                 (Status (..))
+import           Network.Wai
+                 (responseBuilder)
+import           Network.Wai.Internal
+                 (Response (ResponseBuilder))
 import           Servant.API
 import           Servant.Server
 import           Servant.Server.Internal
+import           Test.Hspec
+import           Test.Hspec.Wai
+                 (get, shouldRespondWith, with)
 
 spec :: Spec
 spec = describe "Servant.Server.Internal.Router" $ do
